@@ -3,36 +3,35 @@ package topfew
 import (
 	"bufio"
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
 )
 
-// Sample prints out what amounts to a debugging feed, showing how the filtering and keyrewriting are working.
-func Sample(ioReader io.Reader, filters *Filters, kf *KeyFinder) error {
-
+// sample prints out what amounts to a debugging feed, showing how the filtering and keyrewriting are working.
+func sample(ioReader io.Reader, filters *filters, kf *keyFinder) error {
 	reader := bufio.NewReader(ioReader)
-	for true {
+	for {
 		record, err := reader.ReadBytes('\n')
-		if err == io.EOF {
+		if errors.Is(err, io.EOF) {
 			break
 		} else if err != nil {
 			return err
 		}
 
-		if filters.FilterRecord(record) {
+		if filters.filterRecord(record) {
 			fmt.Print("   ACCEPT: " + string(record))
 		} else {
 			fmt.Print("   REJECT: " + string(record))
+			continue
 		}
-		keyBytes, err := kf.GetKey(record)
+		keyBytes, err := kf.getKey(record)
 		if err != nil {
 			return err
 		}
 
-		filtered := filters.FilterField(keyBytes)
-		if filtered == nil {
-			fmt.Printf("  REJECT: %s\n", string(filtered))
-		} else if bytes.Equal(keyBytes, filtered) {
+		filtered := filters.filterField(keyBytes)
+		if bytes.Equal(keyBytes, filtered) {
 			fmt.Printf("KEY AS IS: %s\n", string(filtered))
 		} else {
 			fmt.Printf("   KEY IN: %s\n", string(keyBytes))
